==> ekyc_id_flutter-1.0.19.tar.gz: android/src/main/kotlin/com/ekycsolutions/ekyc_id_flutter/EkycIdFlutterPlugin.kt <==
package com.ekycsolutions.ekyc_id_flutter

import androidx.annotation.NonNull
import com.ekycsolutions.ekyc_id_flutter.DocumentScanner.DocumentScannerViewFactory
import com.ekycsolutions.ekyc_id_flutter.LivenessDetection.LivenessDetectionViewFactory
import com.ekycsolutions.ekycid.Initializer

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding

/** EkycIdFlutterPlugin */
class EkycIdFlutterPlugin: FlutterPlugin, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity

  private var flutterPluginBinding: FlutterPlugin.FlutterPluginBinding? = null
  private var ekycInitializer: Initializer? = null


  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    this.flutterPluginBinding = flutterPluginBinding
    this.ekycInitializer = Initializer(flutterPluginBinding.applicationContext)
  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    this.flutterPluginBinding = null
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    this.ekycInitializer!!.start {  }
    this.flutterPluginBinding!!.platformViewRegistry.registerViewFactory(
      "DocumentScanner",
      DocumentScannerViewFactory(this.flutterPluginBinding!!, binding.activity)
    )
    this.flutterPluginBinding!!.platformViewRegistry.registerViewFactory(
      "LivenessDetection",
      LivenessDetectionViewFactory(this.flutterPluginBinding!!, binding.activity)
    )
  }


  override fun onDetachedFromActivityForConfigChanges() {
    onDetachedFromActivity()
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    onAttachedToActivity(binding);
  }

  override fun onDetachedFromActivity() {

  }
}

==> ekyc_id_flutter-1.0.20.tar.gz: android/src/main/kotlin/com/ekycsolutions/ekyc_id_flutter/EkycIdFlutterPlugin.kt <==
package com.ekycsolutions.ekyc_id_flutter

import androidx.annotation.NonNull
import com.ekycsolutions.ekyc_id_flutter.DocumentScanner.DocumentScannerViewFactory
import com.ekycsolutions.ekyc_id_flutter.LivenessDetection.LivenessDetectionViewFactory
import com.ekycsolutions.ekycid.EkycID

import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.FlutterPlugin.FlutterPluginBinding
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding

/** EkycIdFlutterPlugin */
class EkycIdFlutterPlugin: FlutterPlugin, ActivityAware {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity

  private var flutterPluginBinding: FlutterPlugin.FlutterPluginBinding? = null
  private var ekycInitializer: EkycID? = null


  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
    this.flutterPluginBinding = flutterPluginBinding
//    this.ekycInitializer = EkycID(flutterPluginBinding.applicationContext)
    EkycID.initialize("",flutterPluginBinding.applicationContext)

  }

  override fun onDetachedFromEngine(@NonNull binding: FlutterPlugin.FlutterPluginBinding) {
    this.flutterPluginBinding = null
  }

  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    this.flutterPluginBinding!!.platformViewRegistry.registerViewFactory(
      "DocumentScanner",
      DocumentScannerViewFactory(this.flutterPluginBinding!!, binding.activity)
    )
    this.flutterPluginBinding!!.platformViewRegistry.registerViewFactory(
      "LivenessDetection",
      LivenessDetectionViewFactory(this.flutterPluginBinding!!, binding.activity)
    )
  }


  override fun onDetachedFromActivityForConfigChanges() {
    onDetachedFromActivity()
  }

  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
    onAttachedToActivity(binding);
  }

  override fun onDetachedFromActivity() {

  }
}
